package com.jdbernard.teammaker

import groovy.beans.Bindable
import javax.swing.BoxLayout

import static com.jdbernard.teammaker.Game.Team.*

public class TeamPanel {

    /* ======== MODEL ======== */ 

    private static def swing = ProfessionalPickup.swing

    ProfessionalPickup main

    // GUI components
    class View {
        def panel
        def teamStatsBox
        def scoreLabel
        def reboundsLabel
        def turnoversLabel
        def playerPanels
        def winsButton
    }
    
    View view = new View()

    class Model {
        //@Bindable String name
        @Bindable Game game
        @Bindable Game.Team team
        @Bindable List players
    }

    Model model = new Model()

    /* ======== VIEW ======== */
    
    private void initGUI() {
        view.panel = swing.vbox {
            
            view.teamStatsBox = hbox {

                vstrut(5)
                view.scoreLabel = label("0")
                vstrut(5)
                view.reboundsLabel = label("Rebs: 0")
                vstrut(5)
                view.turnoversLabel = label("T/Os: 0")
                hglue()
                view.winsButton = button("Winners",
                    actionPerformed: { main.declareWinner(model.team) })
                vstrut(5)
            }
        }

        view.playerPanels = []
    }

    private void initPlayerPanels(List players) {
        view.playerPanels.each { view.panel.remove(it.view.panel) }
        view.playerPanels.clear()

        // create and add player panels
        model.players.each { player ->
            def playerPanel = new PlayerPanel(this, player)
            view.panel << playerPanel.view.panel
            view.playerPanels << playerPanel.view.panel
        }

    }

    /* ======== CONTROLLER ======== */

    public TeamPanel(ProfessionalPickup main, Game.Team team) {
        this.main = main
        model.team = team

        initGUI()
    }

    public void newGame(Game game) {
        model.game = game
        model.players = game.getTeam(model.team)
            
        view.panel.border = swing.titledBorder(model.team.toString())

        initPlayerPanels(model.players)
    }

    public void updateStats() {
        view.scoreLabel = model.game.getTeamScore(model.players)
        view.reboundsLabel = model.game.getTeamRebounds(model.players)
        view.turnoversLabel = model.game.getTeamTurnovers(model.players)
    }
}
